@@ -1,5 +1,5 @@
 """tpcp - Tiny Pipelines for Complicated Problems."""
-from tpcp._algorithm import Algorithm, OptimizableAlgorithm
+from tpcp._algorithm import Algorithm
 from tpcp._algorithm_utils import (
     get_action_method,
     get_action_methods_names,
@@ -23,7 +23,7 @@ from tpcp._parameters import (
 )
 from tpcp._pipeline import OptimizablePipeline, Pipeline
 
-__version__ = "0.6.3"
+__version__ = "0.7.0"
 
 
 __all__ = [
@@ -42,7 +42,6 @@ __all__ = [
     "Parameter",
     "Para",
     "Algorithm",
-    "OptimizableAlgorithm",
     "BaseTpcpObject",
     "Dataset",
     "Pipeline",
